@@ -1,5 +1,6 @@
 from typing import Dict, Optional
 
+from discord.abc import GuildChannel
 from discord.ext.commands import Context
 
 from dpymenus import BaseMenu
@@ -29,6 +30,11 @@ class TextMenu(BaseMenu):
         Manages gathering user input, basic validation, sending messages, and cancellation requests."""
         await super()._validate_pages()
 
+        if not await super().validate_user():
+            return
+
+        await super().set_user_active()
+
         self.output = await self.ctx.send(embed=self.page)
 
         _first_iteration = True
@@ -45,3 +51,9 @@ class TextMenu(BaseMenu):
                 return
 
             await self.page.on_next(self)
+
+    # Internal Methods
+    async def _cleanup_input(self):
+        """Deletes a Discord client user message."""
+        if isinstance(self.ctx.channel, GuildChannel):
+            await self.input.delete(delay=self.delay)
